@@ -2,10 +2,11 @@
 /**
  * useracl.php
  *
- * Copyright (c) 1999-2003 Alexandros Vellis <avel@noc.uoa.gr>
+ * Copyright (c) 1999-2004 Alexandros Vellis <avel@noc.uoa.gr>
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
- * @package useracl
+ * @package plugins
+ * @subpackage useracl
  */
 
 /**
@@ -54,8 +55,12 @@ if(isset($_POST['notify'])) {
 	$notify = false;
 }
 
-if (isset($_POST['adduser'])) {
-	$adduser = $_POST['adduser'];
+if (isset($_POST['adduser']) || isset($_POST['adduser_x']) || isset($_POST['adduser_y'])) {
+	$adduser = true;
+}
+
+if(isset($_POST['newuser'])) {
+	$newuser = $_POST['newuser'];
 }
 
 if(isset($mbox) && isset($addacl)) {
@@ -63,11 +68,11 @@ if(isset($mbox) && isset($addacl)) {
 }
 
 /*  Useful For mail notifications  */
-$identity = getPref($data_dir, $username, 'identities');
+$identity = getPref($data_dir, $username, 'identity');
 if (isset($identity) && $identity != 'default') {
-	$email_address = getPref($data_dir, $username,'email_address' . $identity);
-	$full_name = getPref($data_dir, $username,'full_name' . $identity);
-        // $reply_to = getPref($data_dir, $username,'reply_to' . $identity);
+	$email_address = getPref($data_dir, $username, 'email_address' . $identity);
+	$full_name = getPref($data_dir, $username, 'full_name' . $identity);
+        $reply_to = getPref($data_dir, $username, 'reply_to' . $identity);
 } else {
         $from_mail = getPref($data_dir, $username, 'email_address');
         $full_name = getPref($data_dir, $username, 'full_name');
@@ -137,7 +142,7 @@ if(isset($_POST['update_all'])) {
 		} else {
 			$errormsg[] = sprintf( _("Failed to change permissions for folder %s"), imap_utf7_decode_local($mbox));
 		}
-	} elseif(!isset($_POST['newuser'])) {
+	} elseif(!isset($newuser)) {
 		$errormsg[] = sprintf (_("No changes in permissions for folder %s"), imap_utf7_decode_local($mbox));
 	}
 
@@ -168,7 +173,6 @@ if(isset($_POST['update_all'])) {
 
 } elseif(isset($_POST['delete_checked'])) {
 	/* Delete Checked Permissions */
-	/* FIXME */
 	$delete_checked = $_POST['delete_checked'];
 
 	for($i=0;$i<count($delete_checked);$i++){
@@ -182,7 +186,7 @@ if(isset($_POST['update_all'])) {
 
 }
 
-if(isset($adduser) || (isset($_POST['update_all']) && isset($_POST['newuser']))) {
+if(isset($adduser) || (isset($_POST['update_all']) && isset($newuser))) {
 
 	/* Add New User */
 	$user = trim($_POST['newuser']);
@@ -228,45 +232,55 @@ if(isset($adduser) || (isset($_POST['update_all']) && isset($_POST['newuser'])))
 /* --- Main --- */
 
 
-
-
 /* ------------- Business Logic ---------  */
 
+/* Build folder struct */
 $boxes = sqimap_mailbox_list($imapConnection);
 
-
-for ($boxnum = 0; $boxnum < count($boxes); $boxnum++) {
-	$mbox = $boxes[$boxnum]['unformatted'];
-
-	if(!strstr($mbox, 'INBOX') ||
-	    $mbox == 'INBOX'  ||
+/* 1) Remove folders that are not subfolders of INBOX, if only_inbox == true.
+ * At the same time remove \NoSelect folders. */
+$boxcount = count($boxes);
+for ($boxnum = 0; $boxnum < $boxcount; $boxnum++) {
+	$mb = $boxes[$boxnum]['unformatted'];
+	   
+	if( ( ($useracl_only_inbox == true) &&
+	      (!strstr($mb, 'INBOX') || $mb == 'INBOX') )
+	      ||
 	    in_array('noselect', $boxes[$boxnum]['flags'])) {
+
 		unset($boxes[$boxnum]);
 	}
 }
 
-// print_r($boxes);
+/* 2) For the remaining folders: remove the ones where we do not have admin
+ * access. */
+$boxes = array_values($boxes);
+$boxcount = count($boxes);
+for ($boxnum = 0; $boxnum < $boxcount; $boxnum++) {
+	$mb = $boxes[$boxnum]['unformatted'];
+	if(!strstr(sqimap_myrights($imapConnection, $mb), 'a')) {
+		unset($boxes[$boxnum]);
+	}
+}
 
 $boxes = array_values($boxes);
 
-//print "<b>reorderred</b>";
-//print_r($boxes);
-	    
 
-$usernames = array(); /* Array to gather all usernames together */
+ /* Gather all usernames together in this array. */
+$usernames = array();
 
 foreach($boxes as $no=>$box) {
 
-	$mbox = $box['unformatted'];
+	$mb = $box['unformatted'];
 
 	/* Get ACLs only for subfolders of INBOX */
-	/* FIXME: Alternate namespace */
-	if(strstr($mbox, 'INBOX') && $mbox != 'INBOX' ) {
-		sqimap_getacl($imapConnection, $mbox, $out);
+	if( ($useracl_only_inbox == false) ||
+	    (strstr($mb, 'INBOX') && $mb != 'INBOX' ) ) {
+		sqimap_getacl($imapConnection, $mb, $out);
 		if(array_key_exists($username, $out)) {
 			unset($out[$username]);
 		}
-		$perm[$mbox] = $out;
+		$perm[$mb] = $out;
 	}
 }
 $perm_array = create_human_readable_permarray($perm);
@@ -274,13 +288,23 @@ sqimap_logout($imapConnection);
 
 
 if(isset($ldap)) {
-	/* We require directory plugin */
-	require_once(SM_PATH . 'plugins/directory/functions.php');
+	/* We don't require directory plugin any more. Hopefully. */
+	require_once(SM_PATH . 'plugins/useracl/ldap.php');
+		
 	/* Ask user full names so as to display nicely */
-	foreach($perm as $mbox=>$pe) {
+	foreach($perm as $mb=>$pe) {
 		$usernames = array_merge($usernames, array_keys($pe));
 	}
 
+	/* !!! If removing a user, still keep her here for the data to remain
+	 * for email notification */
+
+	if(isset($perm_prev)) {
+		foreach($perm_prev as $us=>$pe) {
+			$usernames[] = $us;
+		}
+	}
+
 	$usernames=array_unique($usernames);
 	$usernames=array_values($usernames);
 
@@ -344,20 +368,7 @@ if(isset($notify_users) && $notify) {
 	require_once(SM_PATH . 'functions/mime.php');
 	require_once(SM_PATH . 'functions/identity.php');
 
-	/*
-	print "<pre>";
-	print_r($notify_users);
-	// $idents = get_identities();
-	// print_r($idents);
-	// if(sizeof($idents) == 1 ) {
-	// 	print "one identity";
-	// }
-	print "</pre>";
-	*/
-	
 	foreach($notify_users as $n=>$info) {
-		// print "<br><b>Notify ". $no['user'].", ".$no['permission'].", ".$no['mailbox']."</b><br>";
-		
 		$notifyMessage = new Message();
 		$rfc822_header = new Rfc822Header();
 		$notifyMessage->rfc822_header = $rfc822_header;
@@ -373,16 +384,6 @@ if(isset($notify_users) && $notify) {
 			$send_to = $info['user']. $domain;
 		}
 
-		/*
-
-		if($check_user_method == 'ldap') {
-			if (!isset($ldap)) {
-				if(!($ldap=ldap_connect($ldap_server[$ldap_server_no]['host'], $ldap_server[$ldap_server_no]['port']))) {
-				print "Could not connect to LDAP server.";
-			}
-			ldap_search
-			*/
-			
 		if($info['type'] == 'change' && $info['permission'] == 'none') {
 			/* 'remove' */
 			$subject = sprintf("Notification for removal of access to shared folder, by user: %s, Folder: %s",
@@ -427,7 +428,6 @@ if(isset($notify_users) && $notify) {
 		}
 	}
 
-
 	if(isset($successnotify)) {
 		foreach($successnotify as $n=>$info) {
 			if(isset($names[$info['user']])) {
@@ -445,24 +445,9 @@ if(isset($notify_users) && $notify) {
 			$successmsg[] = sprintf( _("Successfully sent notification message to users: %s"), implode(', ',$successprint));
 		}
 	}
-
-
-	/*
-	echo '<form method="post" action="../../src/compose.php">';
-
-	echo '<br />'
-	. '<input type="hidden" name="send_to" value="' . htmlspecialchars($send_to) . '">'
-	. '<input type="hidden" name="subject" value="' . htmlspecialchars($subject) . '">'
-	. '<input type="hidden" name="body" value="' . htmlspecialchars($body) . '">'
-	. '<input type="hidden" name="mailbox" value="' . htmlspecialchars($mailbox) . '">'
-	. '<input type="submit" name="send" value="' . _("Send Mail") . '"><br /><br /></center>'
-	. '</form>'
-	. '</td></tr></table></p></body></html>';
-	*/
 }
 
 
-
 /* ------------- Presentation Logic ---------  */
 
 $js = <<<ECHO
@@ -480,8 +465,6 @@ function SetChecked(val) {
 </script>
 ECHO;
 
-// print "<pre>"; print_r($_POST); print "</pre>";
-
 if ($compose_new_win == '1' && isset($_GET['addacl'])) {
 	displayHtmlHeader(_("Add New User Permission"), '', false);
 } else {
@@ -494,14 +477,6 @@ if ($compose_new_win == '1' && isset($_GET['addacl'])) {
 	textdomain ('useracl');
 }
 
-// echo $js;
-
-/*
-print '<pre>';
-print_r($_POST);
-print '</pre>';
-*/
-
 $prev = bindtextdomain ('useracl', SM_PATH . 'plugins/useracl/locale');
 textdomain ('useracl');
 
@@ -542,8 +517,7 @@ foreach($boxes as $no=>$box) {
 		}
 	}
 
-	if(strstr($mbox, 'INBOX') && $mbox != 'INBOX' && 
-	   (isset($perm_array[$mbox]) || isset($addacl))) {
+	if(isset($perm_array[$mbox]) || isset($addacl)) {
 
 	   	$formname = "form_".str_replace(array('.','%', '-') , array('_','_','_'),
 			rawurlencode($mbox));
@@ -575,7 +549,6 @@ foreach($boxes as $no=>$box) {
 }
 
 
-
 if( ( isset($_GET['addacl']) && !isset($selected_mbox) ) ||
     ( !isset($_GET['addacl']) ) ){
 
@@ -588,7 +561,12 @@ if( ( isset($_GET['addacl']) && !isset($selected_mbox) ) ||
 	print '" method="post">';
 	print '<table width="100%" border="0" >';
 	useracl_print_table_header(true);
-	useracl_print_addnew_separate();
+	
+	if(isset($_POST['mbox'])) {
+		useracl_print_addnew_separate($_POST['mbox']);
+	} else {
+		useracl_print_addnew_separate();
+	}
 	print '</table>';
 	print '</form>';
 	
